Index: tests/service_tests/conformance/java/ConformanceTest.java |
diff --git a/tests/service_tests/conformance/java/ConformanceTest.java b/tests/service_tests/conformance/java/ConformanceTest.java |
index 3aec9acba8b1e212ede441c2d76dd187677a707f..4a6104b7f71b0127683d90606a0673084ccc6c25 100644 |
--- a/tests/service_tests/conformance/java/ConformanceTest.java |
+++ b/tests/service_tests/conformance/java/ConformanceTest.java |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-import fletch.*; |
+import dartino.*; |
import java.io.FileInputStream; |
import java.io.FileNotFoundException; |
@@ -19,13 +19,13 @@ class ConformanceTest { |
System.exit(1); |
} |
- // Load libfletch.so. |
- System.loadLibrary("fletch"); |
+ // Load libdartino.so. |
+ System.loadLibrary("dartino"); |
- // Setup Fletch. |
- FletchApi.Setup(); |
- FletchServiceApi.Setup(); |
- FletchApi.AddDefaultSharedLibrary("libfletch.so"); |
+ // Setup Dartino. |
+ DartinoApi.Setup(); |
+ DartinoServiceApi.Setup(); |
+ DartinoApi.AddDefaultSharedLibrary("libdartino.so"); |
int port = 0; |
try { |